% Clean the screen and remove all the variables in the Workspace

clc
clear all
close all
diary off

% Name of the program

disp('*********************************')
disp('* SOLVING STEADY-STATE BALANCES *')
disp('*********************************')
disp(' ')

% Delete the previously created physical_solution.txt

file_list=dir;
for i=1:length(file_list)
    comp=strcmp('physical_solution.txt',file_list(i).name);
    if comp==1
        delete('physical_solution.txt');
    end
end

% Choose between numerical or analytical solution of the problem

selection=input(' Which type of solution do you prefer, numerical (1) or analytical (2)?: ');
disp(' ')

% Only in case you choose analytical solution

if selection==2
    variables_solve=input(' Write the cell corresponding to the symbolic variables you want to solve {''x1'',''x2'',...}: ');
    disp(' ')
    parameters_syms=input(' Write the cell corresponding to the symbolic parameters of your problem {''p1'',''p2'',...}: ');
    disp(' ')

    elements_solve=length(variables_solve);
    elements_syms=length(parameters_syms);
    
    text_solve='''';
    text_syms=[];
    
    for i=1:elements_solve-1
        text_solve=[text_solve,variables_solve{i},',']; 
    end
    text_solve=[text_solve,variables_solve{elements_solve},''''];
    
    for i=1:elements_syms-1
        text_syms=[text_syms,parameters_syms{i},' '];
    end
    text_syms=[text_syms,parameters_syms{elements_syms}];
    eval(['syms ',text_syms,' real'])
end
    
% Call the file with the steady-state material or energy balance equations

balance_file_name=input(' Steady-state balance file name (without extension): ','s');
disp(' ')
eval(balance_file_name);
number_of_equations=length(eq);

% Solve the algebraic system of equations

if selection==2
    S=solve(eq{1:number_of_equations},eval(text_solve),'Real',true);
else
    S=solve(eq{1:number_of_equations},'Real',true);
end

% Convert the structure array to cell array

C=struct2cell(S);

% Get structure field names, corresponding to the variables

column_1=fieldnames(S);

% Get all the mathematical solutions

for i=1:length(C)
    column=C{i};
    column_2(i,:)=column';
end

% Show all the mathematical solutions

disp(' Mathematical Solutions:')
disp(' ')
disp([column_1,column_2])

% Choose the solution with physical meaning in case there is more than 1
% column in the mathematical solution

number_of_columns=size(column_2,2);
if number_of_columns~=1
    correct_column=input(' Which is the column with results that has physical meaning?: ');
    disp(' ')
else
    correct_column=1;
end

% Get the solution with physical meaning

for i=1:length(C)
    column_3(i)=C{i}(correct_column);
end

% Transpose and simplify the solution

column_3=column_3';
column_3=simplify(column_3);

% Open a text file for writing the physical solution

diary 'physical_solution.txt'

% Show the physical solution

disp(' Physical Solution:')
disp(' ')
disp([column_1,column_3])

% Some additional operations with the variables of the problem

answer=input(' Do you want to perform additional calculations (y,n)?: ','s');
disp(' ')
if (answer=='y'||answer=='Y')
    for i=1:length(C)
        eval([column_1{i},'=',num2str(double(column_3(i))),';'])
    end
    additional_calculus_file_name=input(' Additional calculations file name (without extension): ','s');
    disp(' ')
    eval(additional_calculus_file_name);
end

% Close the text file

diary off
