clc
clear all
close all
bdclose all



disp(' ');
disp('********************************************');
disp('*                Modelo 1                  *');
disp('********************************************');

%% LECTURA Y ADQUISICIN DE DATOS

% Se cargan las condiciones de operacin, constantes, parmetros,
% condiciones iniciales, etc del problema mediante un fichero y se genera
% automticamente la estructura param. Si se necesita informacin 
% adicional, se le pide al usuario que la introduzca. Se suelen  utilizar
% los comandos disp, input, fprintf, switch case, etc.

 datos_modelo_1

variables_workspace=whos;
num_variables=length(variables_workspace);
for i=1:num_variables
    eval(['param.',variables_workspace(i).name,'=',variables_workspace(i).name,';']);
end

%% DEFINICIN DE ELEMENTOS NECESARIOS PREVIOS

% Definicin de funciones, etc. que sean necesarias previamente a la
% resolucin del sistema de EDOs

%% RESOLUCION DEL SISTEMA DE ECUACIONES DIFERENCIALES ORDINARIAS (EDOs)

% Introducimos las condiciones iniciales para cada variable de estado del
% sistema de EDOs y las asignamos a la variable dependiente genrica Y0

Y0=[TG0,DG0,MG0,E0,A0,GL0];

% Definimos el intervalo de integracin de la variable independiente
% genrica X: Xspan=[Xmin Xmax]. El resolvedor adaptar el paso de
% integracin en funcin de los gradientes de la solucin. Otra opcin es
% indicar en qu instantes de tiempo queremos que se resuelva el sistema de
% EDOs.

% Xspan=[0 tmax];
Xspan=linspace(0,tmax,100);

% Identificamos el sistema de EDOs a resolver haciendo uso del fichero
% que contiene la funcin donde se ha definido dicho sistema.

f=@(X,Y) EDOs_modelo_1(X,Y,param);

% Resolvemos el sistema de EDOs con el resolvedor que consideremos
% adecuado, fijando las opciones que nos interesen para el resolvedor,  y
% asignamos los resultados a las variables particulares. Por defecto,
% MaxStep=(Xspan(end)-Xspan(0))/10.

opciones=odeset('RelTol',1e-3,'AbsTol',1e-6,'Refine',10,'MaxStep',[]);
[Xsim,Ysim]=ode15s(f,Xspan,Y0,opciones);

tsim=Xsim;
TGsim=Ysim(:,1);
DGsim=Ysim(:,2);
MGsim=Ysim(:,3);
Esim=Ysim(:,4);
Asim=Ysim(:,5);
GLsim=Ysim(:,6);


%% TRATAMIENTO ADICIONAL DE LA SOLUCIN DEL SISTEMA DE EDOs

% A partir de la solucin proporcionada por el sistema de EDOs, se calculan
% variables adicionales, en caso de que sea necesario, o se hace un
% tratamiento posterior de la solucin para guardarla en ficheros ASCII.

%% REPRESENTACIN GRFICA DE LOS RESULTADOS

% Se har uso de subplot si es necesario. Se aadirn ttulos a los ejes x
% (xlabel) e y (ylabel), as como leyendas a los grficos.


figure(1)
plot(tsim,TGsim,'r')
hold on
plot(tsim,Esim,'b')
hold on
plot(tsim,Asim,'g')
hold on
plot(tsim,MGsim,'c')
hold on
plot(tsim,DGsim,'m')
hold on
plot(tsim,GLsim,'k')
ylabel('C (mol/L)')
xlabel('t (min)')
legend('TG','E','A','MG',...
    'DG','GL')
hold off








